@@ -22,7 +22,7 @@ set_space_around_op <- function(pd_flat, strict) {
     !getOption("styler.ignore_alignment", FALSE) &&
       (
         (is_function_call(pd_flat) && sum_lag_newlines > 2L) ||
-          (is_function_dec(pd_flat) && sum_lag_newlines > 1L)
+          (is_function_declaration(pd_flat) && sum_lag_newlines > 1L)
       ) &&
       any(pd_flat$token %in% c("EQ_SUB", "','", "EQ_FORMALS"))
   ) {
@@ -96,10 +96,8 @@ style_space_around_token <- function(pd_flat,
     pd_flat$spaces[idx_before] <- level_before
     pd_flat$spaces[idx_after] <- level_after
   } else {
-    pd_flat$spaces[idx_before] <-
-      pmax(pd_flat$spaces[idx_before], level_before)
-    pd_flat$spaces[idx_after] <-
-      pmax(pd_flat$spaces[idx_after], level_after)
+    pd_flat$spaces[idx_before] <- pmax(pd_flat$spaces[idx_before], level_before)
+    pd_flat$spaces[idx_after] <- pmax(pd_flat$spaces[idx_after], level_after)
   }
   pd_flat
 }
@@ -110,12 +108,15 @@ style_space_around_tilde <- function(pd_flat, strict) {
       strict, "'~'",
       level_before = 1L, level_after = 1L
     )
-  } else if (is_asymmetric_tilde_expr(pd_flat)) {
+  }
+
+  if (is_asymmetric_tilde_expr(pd_flat)) {
     pd_flat <- style_space_around_token(pd_flat,
       strict = TRUE, "'~'", level_before = 1L,
       level_after = as.integer(nrow(pd_flat$child[[2L]]) > 1L)
     )
   }
+
   pd_flat
 }
 
@@ -286,7 +287,7 @@ start_comments_with_space <- function(pd, force_one = FALSE) {
       comments$text
     ) %>%
     trimws("right")
-  pd$short[is_comment] <- substr(pd$text[is_comment], 1, 5)
+  pd$short[is_comment] <- substr(pd$text[is_comment], 1L, 5L)
   pd
 }
 
@@ -345,20 +346,16 @@ remove_space_after_fun_dec <- function(pd_flat) {
 }
 
 remove_space_around_colons <- function(pd_flat) {
-  one_two_or_three_col_after <-
-    pd_flat$token %in% c("':'", "NS_GET_INT", "NS_GET")
+  one_two_or_three_col_after <- pd_flat$token %in% c("':'", "NS_GET_INT", "NS_GET")
+  one_two_or_three_col_before <- lead(one_two_or_three_col_after, default = FALSE)
 
-  one_two_or_three_col_before <-
-    lead(one_two_or_three_col_after, default = FALSE)
-
-  col_around <-
-    one_two_or_three_col_before | one_two_or_three_col_after
+  col_around <- one_two_or_three_col_before | one_two_or_three_col_after
 
   pd_flat$spaces[col_around & (pd_flat$newlines == 0L)] <- 0L
   pd_flat
 }
 
-#' Set space between EQ_SUB and "','"
+#' Set space between `EQ_SUB` and `"','"`
 #' @param pd A parse table.
 #' @keywords internal
 set_space_between_eq_sub_and_comma <- function(pd) {
