@@ -7,19 +7,21 @@
 #' @importFrom rlang seq2
 #' @keywords internal
 set_unindention_child <- function(pd, token = "')'", unindent_by) {
-  if (all(pd$indent == 0) || all(pd$terminal)) {
+  if (all(pd$indent == 0L) || all(pd$terminal)) {
     return(pd)
   }
   closing <- which(pd$token %in% token)
-  if (length(closing) == 0 || pd$lag_newlines[closing] > 0) {
+  if (length(closing) == 0L || pd$lag_newlines[closing] > 0L) {
     return(pd)
   }
 
-  first_on_last_line <- last(c(1, which(pd$lag_newlines > 0 | pd$multi_line > 0)))
+  first_on_last_line <- last(
+    c(1, which(pd$lag_newlines > 0L | pd$multi_line > 0L))
+  )
   on_same_line <- seq2(first_on_last_line, closing - 1)
   cand_ind <- setdiff(on_same_line, which(pd$terminal))
 
-  if (length(cand_ind) < 1) {
+  if (length(cand_ind) < 1L) {
     return(pd)
   }
 
@@ -29,7 +31,7 @@ set_unindention_child <- function(pd, token = "')'", unindent_by) {
 
   candidates$child <- map(candidates$child,
     unindent_child,
-    unindent_by = abs(pd$indent[closing] - pd$indent[closing - 1])
+    unindent_by = abs(pd$indent[closing] - pd$indent[closing - 1L])
   )
 
   bind_rows(candidates, non_candidates) %>%
@@ -42,12 +44,12 @@ set_unindention_child <- function(pd, token = "')'", unindent_by) {
 #' @param token The token the unindention should be based on.
 #' @param unindent_by By how many spaces one level of indention is reversed.
 #' @keywords internal
-unindent_child <- function(pd, token = c("')'", "'}'"), unindent_by = 2) {
+unindent_child <- function(pd, token = c("')'", "'}'"), unindent_by = 2L) {
   closing <- which(pd$token %in% token)
   if (!("indent" %in% names(pd))) {
-    pd$indent <- 0
+    pd$indent <- 0L
   }
-  if ((length(closing) > 0) && (closing == nrow(pd))) {
+  if ((length(closing) > 0L) && (closing == nrow(pd))) {
     pd$indent[closing] <- pd$indent[closing] - unindent_by
   }
   pd
