@@ -4,6 +4,19 @@ line_col_names <- function() {
   c("line1", "line2", "col1", "col2")
 }
 
+#' Wrapper functions to encapsulate data frame creation
+#' @keywords internal
+#' @noRd
+styler_df <- function(...) {
+  vctrs::data_frame(..., .name_repair = "minimal")
+}
+
+#' @keywords internal
+#' @noRd
+new_styler_df <- function(x) {
+  vctrs::new_data_frame(x)
+}
+
 #' Ensure there is one (and only one) blank line at the end of a vector
 #' @examples
 #' styler:::ensure_last_n_empty("")
@@ -15,10 +28,36 @@ ensure_last_n_empty <- function(x, n = 1) {
     return("")
   }
   x <- c(x, "", "")
-  x <- x[seq(1, length(x) - which(rev(x) != "")[1] + 1L)]
+  x <- x[seq(1, length(x) - which(rev(x) != "")[1L] + 1L)]
   c(x, rep("", n))
 }
 
+#' @note Slightly simplified version of `rematch2::re_match()` (License: MIT).
+#' @keywords internal
+#' @noRd
+re_match <- function(text, pattern) {
+  stopifnot(is.character(pattern), length(pattern) == 1L, !is.na(pattern))
+  text <- as.character(text)
+  match <- regexpr(pattern, text, perl = TRUE)
+  start <- as.vector(match)
+  length <- attr(match, "match.length")
+  end <- start + length - 1L
+  matchstr <- substring(text, start, end)
+  matchstr[start == -1] <- NA_character_
+  res <- data.frame(stringsAsFactors = FALSE, .text = text, .match = matchstr)
+
+  gstart <- attr(match, "capture.start")
+  glength <- attr(match, "capture.length")
+  gend <- gstart + glength - 1L
+  groupstr <- substring(text, gstart, gend)
+  groupstr[gstart == -1] <- NA_character_
+  dim(groupstr) <- dim(gstart)
+  res <- cbind(groupstr, res, stringsAsFactors = FALSE)
+
+  names(res) <- c(attr(match, "capture.names"), ".text", ".match")
+  res
+}
+
 #' Replace the newline character with a line break
 #'
 #' @param text A character vector
@@ -36,38 +75,18 @@ convert_newlines_to_linebreaks <- function(text) {
   } else {
     .x
   }) %>%
-    unlist()
-}
-
-#' Check whether two columns match
-#'
-#' @param col1,col2 Column names as string.
-#' @param data The data frames that contains `col1` and `col2`.
-#' @keywords internal
-two_cols_match <- function(col1, col2, data) {
-  all(unlist(data[col1]) == unlist(data[col2]))
-}
-
-odd <- function(x) {
-  x[odd_index(x)]
+    unlist(use.names = FALSE)
 }
 
 odd_index <- function(x) {
-  if (length(x) < 1) {
+  if (length(x) < 1L) {
     return(NULL)
   }
-  seq(1L, length(x), by = 2)
-}
-
-even <- function(x) {
-  if (length(x) < 2) {
-    return(NULL)
-  }
-  x[even_index(x)]
+  seq(1L, length(x), by = 2L)
 }
 
 even_index <- function(x) {
-  seq(2L, length(x), by = 2)
+  seq(2L, length(x), by = 2L)
 }
 
 is_windows <- function() {
@@ -87,6 +106,7 @@ calls_sys <- function(sys_call, ...) {
   } else {
     error <- system(sys_call, ...)
   }
+  error
 }
 
 #' Get the value of an option
@@ -97,14 +117,14 @@ calls_sys <- function(sys_call, ...) {
 #'   option was not set.
 #' @keywords internal
 option_read <- function(x, default = NULL, error_if_not_found = TRUE) {
-  if (x %in% names(options()) | !error_if_not_found) {
+  if (x %in% names(options()) || !error_if_not_found) {
     getOption(x, default)
   } else {
     rlang::abort(paste("R option", x, "must be set."))
   }
 }
 
-
+#' @keywords internal
 unwhich <- function(x, length) {
   x_ <- rep(FALSE, length)
   x_[x] <- TRUE
