@@ -1,5 +1,3 @@
-context("test-roxygen-examples-complete")
-
 test_that("analogous to test-roxygen-examples-complete", {
   expect_warning(test_collection(
     "roxygen-examples-complete", "^1[^1234567890]",
@@ -136,4 +134,9 @@ test_that("analogous to test-roxygen-examples-complete", {
     "roxygen-examples-complete", "^26",
     transformer = style_text
   ), NA)
+
+  expect_warning(test_collection(
+    "roxygen-examples-complete", "^27",
+    transformer = style_text
+  ), NA)
 })
